@@ -1,4 +1,4 @@
-from .message import Message, Text, Command, Contact, Document, Photo
+from .message import Message, Text, Command, Contact, Document, Photo, Animation
 from .state import State
 from .user_id import UserId
 from .chat_type import ChatType
